==> ja-xdtp-1.1.4.tbz: include/xdtp/Exception.h <==
/* 
 * $Id: Exception.h,v 1.5 2005/10/04 10:58:12 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.5 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___EXCEPTION_H
#define ___EXCEPTION_H

#include "glibmm.h"

#ifdef DEBUG
#define THROW(USER_MSG)     { \
                                char ___line[6] = {0}; \
                                Glib::ustring ___msg = "Exception occured: "; \
                                snprintf(___line, sizeof(___line) -1, "%d", __LINE__); \
                                ___msg += __FILE__ " ("; \
                                ___msg += ___line; \
                                ___msg += ")" LINE_SEP "\t"; \
                                ___msg += USER_MSG; \
                                throw XDTP::Exception(___msg); \
                            }
#else
#define THROW(USER_MSG)     throw XDTP::Exception(USER_MSG)
#endif

namespace XDTP {

class Exception
{
public:
	Exception();
    Exception(const Glib::ustring& msg);
    Exception(const Exception& exception);
	virtual ~Exception();
    
    const Exception& operator=(const Exception& exception);
    
    void print(FILE* out);
    Glib::ustring what();

private:
    Glib::ustring m_msg;
};

};

#endif

==> ja-xdtp-1.3.1_4.tbz: include/xdtp/Exception.h <==
/* 
 * $Id: Exception.h,v 1.7 2008/11/19 08:06:49 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.7 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___EXCEPTION_H
#define ___EXCEPTION_H

#include "glibmm.h"

#include <string>
#include <exception>

#ifdef DEBUG
#define THROW(USER_MSG)     { \
                                char ___line[6] = {0}; \
                                Glib::ustring ___msg = "Exception occured: "; \
                                snprintf(___line, sizeof(___line) -1, "%d", __LINE__); \
                                ___msg += __FILE__ " ("; \
                                ___msg += ___line; \
                                ___msg += ")" LINE_SEP "\t"; \
                                ___msg += USER_MSG; \
                                throw XDTP::Exception(___msg); \
                            }
#else
#define THROW(USER_MSG)     throw XDTP::Exception(USER_MSG)
#endif

namespace XDTP {

class Exception : public std::exception
{
public:
	Exception() throw();
    Exception(const std::string& msg) throw();
    Exception(const std::exception& exception) throw();
	virtual ~Exception() throw();
    
    const Exception& operator=(const std::exception& exception);
    
    void print(FILE* out);
    static void print(FILE* out, const std::exception& exception);
    
	virtual const char* what() const throw();

private:
    std::string m_msg;
};

};

#endif
